/*******************************************************************************
 * BerthaFunctionPrototypes.h
 * target: PushpinV3
 *
 * Josh Lifton
 * lifton@media.mit.edu
 * MIT Media Lab
 * Copyright 2002 all rights reserved.
 *
 * Last modified 03OCT2002 by lifton.
 *
 * This file contains all function prototypes needed to compile the Bertha 
 * operating system.  Function prototypes are listed in alphabetical order 
 * by function name and grouped according to the file they are defined in.
 *******************************************************************************/

/* BerthaOS.c */
//unsigned int getBerthaVersion(void);

/* BerthaFunctions.c -- Functions available only to Bertha. */
void configurePins(void);
void disableWatchdogTimer(void);
unsigned char enableADCChannel(unsigned char);
void enableExternalClock(void);
void initializeHardware(void);
void monitorADCWindow(unsigned char, unsigned int, unsigned int);
void setRandomSeed(int);
void copyXdataToFlash(unsigned char code *, unsigned char xdata *, unsigned int);
void saveOSState(OSState xdata *);

/* Messaging.c -- Higher level messaging than BerthaCommunication.c. */
void addToMessageQueue(unsigned char, unsigned char, unsigned int, unsigned char, unsigned long, Message xdata *);
void checkMessageQueue(void);
unsigned char findMessage(unsigned char);
void initializeMessage(Message xdata *);
void initializeMessaging(void);
void nextMessage(void);
void processIncomingMessage(Message xdata * messagePtr);
void propagateOS(void);
void removeFromMessageQueue(unsigned char);

/* BerthaCommunication.c -- Functions to handle communication. */
void delay(unsigned int);
void detectCommModule(void);
void disableCommunication(void);
void enableCommunication(void);
void flashLED(unsigned int, unsigned int);
unsigned int getADCValue(unsigned char);
unsigned char getNextPacketByte(void);
unsigned char xdata *  getContentPtr(void);
unsigned char packetCRC8(Packet xdata *);
void packetReceived(void);
void packetReceiveError(void);
void packetSent(void);
unsigned char queuePacketForTransmission(PushpinLocalID, unsigned char, XdataAddress, unsigned char xdata *);
void receivedByte(unsigned char);
void serialInterrupt(void);
void setCommMode(unsigned char);
void setNextPacketByte(unsigned char);
unsigned char attemptToSendPacket(void);
void timer2Interrupt(void);

/* BerthaTiming.c -- Management of real-time clock and timers. */
void startRealTimeClock(void);
unsigned long getTime(void);
void setTime(unsigned long);
void timer0Interrupt(void);

/* ExpansionModules.c -- Configuration and use of expansion modules. */
void enableLDRModule(void);
void calibrateLDR(unsigned int);
void clearLEDDisplay(void);
void flashLDRLED(unsigned char, unsigned int, unsigned int, unsigned char);
signed int getLDRValue(void);
void monitorLDR(unsigned int);
void setLEDIntensity(unsigned char, unsigned char);

/* codecs.c -- Lookup tables and some associated functions. */
unsigned char getFlashBlockCRC8(unsigned char code*, unsigned int);

/* OSOverwrite.c -- functions for overwriting Bertha that themselves shouldn't be overwritten. */
void copyFlashBlock(unsigned char code *, unsigned char code *, unsigned int);
void overwriteOS(unsigned char code *, unsigned char code *, unsigned int);
void clearFlashMemory(unsigned char code *, unsigned int);
