/*******************************************************************
 * BerthaOS.c
 * target: PushpinV3
 *
 * Josh Lifton
 * lifton@media.mit.edu
 * MIT Media Lab
 * Copyright 2002 all rights reserved.
 *
 * Last modified 30MAY2002 by lifton.
 *
 * This is Bertha, the operating system for Pushpins.
 *******************************************************************/

#include <c8051F000.h>
#include <PushpinHardwareV3.h>
#include <Bertha.h>
#include <BerthaFunctionPrototypes.h>
#include <BerthaGlobals.h>
#include <stdlib.h>

PushpinLocalID xdata NeighborhoodID = GLOBALADDRESS + 1;
unsigned int xdata timeScale = DEFAULTTIMESCALE;
const OSState code osState _at_ MiniPageAddress;

void main(void) {
	/* 
	 * Initialization. 
	 */
	initializeHardware();
	setRandomSeed(osState.randomSeed);
	enableGlobalInterrupts();
	startRealTimeClock();
	detectCommModule();
	enableLDRModule();
	disableCommunication();
	initializeMessaging();
	enableCommunication();
	/*
	 * Indicate on-board initialization complete.
	 */
	flashLED(commMode,0xFFFF);

	/*
	 * Check if this Pushpin is waking up because a new OS 
	 * was installed.
	 */
	if (!(osState.isOld)) {
		propagateOS();
	}

	/* Control loop. */
	while (1) {

		/*
		 * Check alarms for queued messages.
		 */
		checkMessageQueue();

		/*
		 * Make sure all packets eventually get sent.
		 */
		attemptToSendPacket();

		/*
		 * Do nothing for a while.
		 */
		delay(DELAYTIME);

	}
}